@@ -10,16 +10,19 @@ from spark_pipeline_framework.proxy_generator.python_proxy_base import PythonPro
 class FeatureCarrierPythonTransformer(PythonProxyBase):
     # noinspection PyUnusedLocal
     @keyword_only
-    def __init__(self,
-                 name: str = None,
-                 parameters: Optional[Dict[str, Any]] = None,
-                 progress_logger: Optional[ProgressLogger] = None,
-                 verify_count_remains_same: bool = False
-                 ) -> None:
-        super().__init__(name=name,
-                         parameters=parameters,
-                         progress_logger=progress_logger,
-                         verify_count_remains_same=verify_count_remains_same)
+    def __init__(
+        self,
+        name: str = None,
+        parameters: Optional[Dict[str, Any]] = None,
+        progress_logger: Optional[ProgressLogger] = None,
+        verify_count_remains_same: bool = False
+    ) -> None:
+        super().__init__(
+            name=name,
+            parameters=parameters,
+            progress_logger=progress_logger,
+            verify_count_remains_same=verify_count_remains_same
+        )
         assert parameters
         assert progress_logger
 
