@@ -5,4 +5,7 @@ def get_first_class_in_module(module):
     :return:
     """
     md = module.__dict__
-    return [md[c] for c in md if (isinstance(md[c], type) and md[c].__module__ == module.__name__)][0]
+    return [
+        md[c] for c in md
+        if (isinstance(md[c], type) and md[c].__module__ == module.__name__)
+    ][0]
